@@ -5,7 +5,6 @@
 */
 
 #include "ConnectionXillybus.h"
-#include "ErrorReporting.h"
 #ifndef __unix__
 #include "Windows.h"
 #else
@@ -63,9 +62,6 @@ const ConnectionXillybus::EPConfig ConnectionXillybus::deviceConfigs[] = {
 */
 ConnectionXillybus::ConnectionXillybus(const unsigned index)
 {
-    RxLoopFunction = bind(&ConnectionXillybus::ReceivePacketsLoop, this, std::placeholders::_1);
-    TxLoopFunction = bind(&ConnectionXillybus::TransmitPacketsLoop, this, std::placeholders::_1);
-
     m_hardwareName = "";
 #ifndef __unix__
     hWrite = INVALID_HANDLE_VALUE;
@@ -81,7 +77,6 @@ ConnectionXillybus::ConnectionXillybus(const unsigned index)
     Open(index);
     isConnected = true;
 
-    GetChipVersion();
     std::shared_ptr<Si5351C> si5351module(new Si5351C());
     si5351module->Initialize(this);
     si5351module->SetPLL(0, 25000000, 0);
@@ -306,6 +301,17 @@ int ConnectionXillybus::Write(const unsigned char *buffer, const int length, int
         ReportError(errno);
         break;
     }
+#else
+    if (totalBytesWritten != length)
+    {
+        CloseHandle(hWrite);
+        hWrite = CreateFileA(writeCtrlPort.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_OVERLAPPED, 0);
+        if (hWrite == INVALID_HANDLE_VALUE)
+        {
+            CloseHandle(hRead);
+            hWrite = INVALID_HANDLE_VALUE;
+        }
+     }
 #endif
     return totalBytesWritten;
 }
@@ -373,9 +379,31 @@ int ConnectionXillybus::Read(unsigned char *buffer, const int length, int timeou
 
     }while (std::chrono::duration_cast<std::chrono::milliseconds>(chrono::high_resolution_clock::now() - t1).count() < timeout_ms);
 
+#ifndef __unix__
+    if (totalBytesReaded != length)
+    {
+        CloseHandle(hRead);
+        hRead = CreateFileA(readCtrlPort.c_str(), GENERIC_READ, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_OVERLAPPED, 0);
+        if (hRead == INVALID_HANDLE_VALUE)
+        {
+            CloseHandle(hRead);
+            hRead = INVALID_HANDLE_VALUE;
+        }
+    }
+#endif
     return totalBytesReaded;
 }
 
+int ConnectionXillybus::GetBuffersCount() const 
+{
+    return 1;
+};
+
+int ConnectionXillybus::CheckStreamSize(int size) const 
+{
+    return size < 4 ? 4 : size;
+};
+
 /**
     @brief Reads data from board
     @param buffer array where to store received data
@@ -587,3 +615,29 @@ void ConnectionXillybus::AbortSending(int epIndex)
     }
 #endif
 }
+
+int ConnectionXillybus::BeginDataReading(char* buffer, uint32_t length, int ep) 
+{
+    return ep;
+}
+bool ConnectionXillybus::WaitForReading(int contextHandle, unsigned int timeout_ms) 
+{
+    return true;
+}
+int ConnectionXillybus::FinishDataReading(char* buffer, uint32_t length, int contextHandle)
+{
+    return ReceiveData(buffer, length, contextHandle, 3000);
+}
+
+int ConnectionXillybus::BeginDataSending(const char* buffer, uint32_t length, int ep) 
+{
+    return SendData(buffer, length,  ep, 3000);
+}
+bool ConnectionXillybus::WaitForSending(int contextHandle, uint32_t timeout_ms) 
+{
+    return true;
+}
+int ConnectionXillybus::FinishDataSending(const char* buffer, uint32_t length, int contextHandle) 
+{
+    return contextHandle;
+}
