@@ -11,7 +11,7 @@
 #include "lime/LimeSuite.h"
 
 
-class LMS7002M_Novena_wxgui : public wxFrame
+class LMS7002M_Novena_wxgui : public wxPanel
 {
 public:
     LMS7002M_Novena_wxgui(wxWindow* parent, wxWindowID id = wxID_ANY, const wxString &title = wxEmptyString, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long styles = 0);
@@ -20,13 +20,13 @@ public:
     virtual void UpdatePanel();
 
     wxCheckBox *lms_reset, *lms_rxen, *lms_txen, *lms_gpio2, *lms_gpio1, *lms_gpio0;
-    wxButton* btnReadAll;
 protected:
     void ParameterChangeHandler(wxCommandEvent& event);
     void OnReadAll(wxCommandEvent& event);
+    void OnWriteAll(wxCommandEvent &event);
     lms_device_t* lmsControl;
     int m_rficSpiAddr;
-
+    DECLARE_EVENT_TABLE();
 };
 
 #endif //LMS7002M_NOVENA_H
