@@ -118,6 +118,8 @@ API_EXPORT int CALL_CONV LMS_Close(lms_device_t *device);
 /**
  * Disconnect device but keep configuration cache (device is not deallocated).
  *
+ * @deprecated use LMS_Close() to disconnect and close device
+ *
  * @param   device  Device handle previously obtained by LMS_Open().
  *
  * @return   0 on success, (-1) on failure
@@ -127,6 +129,8 @@ API_EXPORT int CALL_CONV LMS_Disconnect(lms_device_t *device);
 /**
  * Check if device port is opened
  *
+ * @deprecated use return status of LMS_Open() as indication. 
+ *
  * @param   device  Device handle previously obtained by LMS_Open().
  * @param   port    port index (ignored if device has only 1 port)
  *
@@ -254,9 +258,11 @@ API_EXPORT int CALL_CONV LMS_GetSampleRateRange(lms_device_t *device, bool dir_t
 /**
  * Set RF center frequency in Hz.
  *
- * @note setting different frequencies for A and B channels is not supported by
- * LMS7 chip. Changing frequency for one (A or B) channel will result in
- * frequency being changed for both (A and B) channels.
+ * @note channels A and B in LMS7 chip share the same clock so ability to set
+ * different frequencies for channels A and B is very limited. This function 
+ * will attempt to achieve diffrent requested frequencies using NCO when 
+ * possible, however often changing frequency for one (A or B) channel will
+ * result in frequency being changed for both (A and B) channels.
  *
  * @param   device      Device handle previously obtained by LMS_Open().
  * @param   dir_tx      Select RX or TX
@@ -387,7 +393,7 @@ API_EXPORT int CALL_CONV LMS_SetNormalizedGain(lms_device_t *device, bool dir_tx
  * @param   device      Device handle previously obtained by LMS_Open().
  * @param   dir_tx      Select RX or TX
  * @param   chan        Channel index
- * @param   gain        Desired gain, range [0, 70] for RX, [0, 60] for TX
+ * @param   gain        Desired gain, range [0, 73]
  * @return  0 on success, (-1) on failure
  */
 API_EXPORT int CALL_CONV LMS_SetGaindB(lms_device_t *device, bool dir_tx,
@@ -417,7 +423,7 @@ API_EXPORT int CALL_CONV LMS_GetNormalizedGain(lms_device_t *device, bool dir_tx
  * @param       device      Device handle previously obtained by LMS_Open().
  * @param       dir_tx      Select RX or TX
  * @param       chan        Channel index
- * @param[out]  gain        Current gain, range [0, 70], [0, 60] for TX
+ * @param[out]  gain        Current gain
  * @return  0 on success, (-1) on failure
  */
 API_EXPORT int CALL_CONV LMS_GetGaindB(lms_device_t *device, bool dir_tx,
@@ -905,7 +911,7 @@ API_EXPORT int CALL_CONV LMS_WriteCustomBoardParam(lms_device_t *device,
  * Get frequency of the specified clock.
  *
  * @param   dev     Device handle previously obtained by LMS_Open().
- * @param   clk_id  Clock identifier
+ * @param   clk_id  Clock identifier (\ref LMS_CLOCK_ID)
  * @param   freq    Clock frequency in Hz
  *
  * @return 0 on success, (-1) on failure
@@ -920,7 +926,7 @@ API_EXPORT int CALL_CONV LMS_GetClockFreq(lms_device_t *dev, size_t clk_id,
  * ::LMS_VCTCXOWrite() to change back to VCTCXO
  *
  * @param   dev     Device handle previously obtained by LMS_Open().
- * @param   clk_id  Clock identifier
+ * @param   clk_id  Clock identifier (\ref LMS_CLOCK_ID)
  * @param   freq    Clock frequency in Hz. Pass zero or negative value to only
  *                  perform tune (if supported) without recalculating values
  *
@@ -1079,7 +1085,7 @@ typedef struct
     uint32_t overrun;
     ///Number of dropped packets by HW
     uint32_t droppedPackets;
-    ///Sampling rate of the stream
+    ///Currently not used
     float_type sampleRate;
     ///Combined data rate of all stream of the same direction (TX or RX)
     float_type linkRate;
@@ -1198,22 +1204,15 @@ API_EXPORT int CALL_CONV LMS_EnableTxWFM(lms_device_t *device, unsigned chan, bo
  * @{
  */
 
-/**Enumeration of programming mode*/
-typedef enum
-{
-    LMS_PROG_MD_RAM = 0,   ///<load firmware/bitstream to volatile storage
-    LMS_PROG_MD_FLASH = 1, ///<load firmware/bitstream to non-volatile storage
-    LMS_PROG_MD_RST = 2    ///<reset and boot from flash
-}lms_prog_md_t;
-
-/**Enumeration of programmable board modules*/
-typedef enum
-{
-    LMS_PROG_TRG_FX3 = 0,   ///<program FX3 firmware
-    LMS_PROG_TRG_FPGA,      ///<program FPGA gateware
-    LMS_PROG_TRG_MCU,       ///<program LMS7 MCU firmware
-    LMS_PROG_TRG_HPM7,
-}lms_prog_trg_t;
+/**
+ * Get the list of supported programming modes.
+ * 
+ * @param device        Device handle previously obtained by LMS_Open().
+ * @param[out]  list    list of programming modes (can be NULL).
+ * 
+ * @return      number of modes in the list, (-1) on failure
+ */
+API_EXPORT int CALL_CONV LMS_GetProgramModes(lms_device_t *device, lms_name_t *list);
 
 /**
  * Callback from programming processes
@@ -1230,26 +1229,13 @@ typedef bool (*lms_prog_callback_t)(int bsent, int btotal, const char* progressM
  * @param device    Device handle previously obtained by LMS_Open().
  * @param data      Pointer to memory containing firmware/bitsteam image
  * @param size      Size of firmware/bitsteam image in bytes.
- * @param target   device component to program ::lms_prog_trg_t
- * @param mode      programming mode ::lms_prog_md_t
+ * @param mode      programming mode, use LMS_GetProgramModes to get list of modes 
  * @param callback  callback function for monitoring progress
  *
  * @return          0 on success, (-1) on failure
  */
-API_EXPORT int CALL_CONV LMS_Program(lms_device_t *device, const char *data, size_t size,
-           lms_prog_trg_t target, lms_prog_md_t mode, lms_prog_callback_t callback);
-
-/**
- * Automatically update device firmware
- *
- * @param dev       Device handle previously obtained by LMS_Open().
- * @param download  True to download missing images from the web.
- * @param callback  callback function for monitoring progress
- *
- * @return          0 on success, (-1) on failure
- */
-API_EXPORT int CALL_CONV LMS_ProgramUpdate(lms_device_t *dev, bool download,
-                                           lms_prog_callback_t callback);
+API_EXPORT int CALL_CONV LMS_Program(lms_device_t *device, const char *data, 
+                size_t size, const lms_name_t mode, lms_prog_callback_t callback);
 
 /**Device information structure*/
 typedef struct
@@ -1259,9 +1245,8 @@ typedef struct
     char firmwareVersion[16];       ///<The firmware version as a string
     char hardwareVersion[16];       ///<The hardware version as a string
     char protocolVersion[16];       ///<The protocol version as a string
-    uint32_t boardSerialNumber;     ///<A unique board serial number
+    uint64_t boardSerialNumber;     ///<A unique board serial number
     char gatewareVersion[16];       ///<Gateware version as a string
-    char gatewareRevision[16];      ///<Gateware revision as a string
     char gatewareTargetBoard[32];   ///<Which board should use this gateware
 }lms_dev_info_t;
 
@@ -1285,15 +1270,32 @@ API_EXPORT const char* LMS_GetLibraryVersion();
 
 /**
  * Get the error message detailing why the last error occurred.
+ * 
+ * @deprecated use LMS_RegisterLogHandler() to obtain error messages
  *
  * @return last error message.
  */
 API_EXPORT const char * CALL_CONV LMS_GetLastErrorMessage(void);
 
+/**
+ * @defgroup LMS_LOG_LEVEL  Message logging level
+ *
+ * @{
+ */
+///An error message . An operation did not complete successfully.
+#define LMS_LOG_ERROR    1  
+///A warning message. An operation completed with an unexpected result.
+#define LMS_LOG_WARNING  2  
+///An informational message, usually denoting the successful completion of an operation
+#define LMS_LOG_INFO     3  
+ ///A debugging message.
+#define LMS_LOG_DEBUG    4 
+/** @} (End LMS_LOG_LEVEL) */
+
 /**
  * Callback function for redirecting API messages
  * 
- * @param lvl   lower value represents higher priority/importance message, range [0,4].
+ * @param lvl   \ref LMS_LOG_LEVEL.
  * @param msg   string containing log message text.
  */
  typedef void (*LMS_LogHandler)(int lvl, const char *msg);
