@@ -31,6 +31,7 @@ lms7002_pnlCalibrations_view::lms7002_pnlCalibrations_view(wxWindow* parent, wxW
     wndId2Enum[chkDCMODE] = LMS7param(DCMODE);
 
     LMS7002_WXGUI::UpdateTooltips(wndId2Enum, true);
+    rgrCalibrationMethod->Hide();
 }
 
 void lms7002_pnlCalibrations_view::OnbtnCalibrateRx(wxCommandEvent& event)
@@ -56,12 +57,13 @@ void lms7002_pnlCalibrations_view::OnbtnCalibrateRx(wxCommandEvent& event)
         status = LMS_Calibrate(lmsControl, LMS_CH_RX, ch, bandwidth_MHz * 1e6, flags);
     }
     if (status != 0)
-        wxMessageBox(wxString::Format(_("Rx calibration: %s"), wxString::From8BitData(LMS_GetLastErrorMessage())));
+        wxMessageBox(wxString::Format(_("Rx calibration failed: %s"), LMS_GetLastErrorMessage()));
     else
     {
         wxMessageBox(_("Rx Calibration Finished"), _("Info"), wxOK, this);
         wxCommandEvent evt;
         evt.SetEventType(LOG_MESSAGE);
+        evt.SetInt(lime::LOG_LEVEL_INFO);
         evt.SetString(_("Rx Calibrated"));
         wxPostEvent(this, evt);
     }
@@ -89,12 +91,13 @@ void lms7002_pnlCalibrations_view::OnbtnCalibrateTx( wxCommandEvent& event )
         status = LMS_Calibrate(lmsControl,LMS_CH_TX,ch-1,bandwidth_MHz * 1e6,useExtLoopback);
     }
     if (status != 0)
-        wxMessageBox(wxString::Format(_("Tx calibration: %s"), wxString::From8BitData(LMS_GetLastErrorMessage())));
+        wxMessageBox(wxString::Format(_("Tx calibration failed: %s"), LMS_GetLastErrorMessage()));
     else
     {
         wxMessageBox(_("Tx Calibration Finished"), _("Info"), wxOK, this);
         wxCommandEvent evt;
         evt.SetEventType(LOG_MESSAGE);
+        evt.SetInt(lime::LOG_LEVEL_INFO);
         evt.SetString(_("Tx Calibrated"));
         wxPostEvent(this, evt);
     }
@@ -117,25 +120,20 @@ void lms7002_pnlCalibrations_view::OnbtnCalibrateAll( wxCommandEvent& event )
     }
     uint16_t ch;
     LMS_ReadParam(lmsControl,LMS7param(MAC),&ch);
-    int status;
-    {
-#ifdef NDEBUG
-        wxBusyInfo wait("Please wait, calibrating transmitter...");
-#endif
-        status = LMS_Calibrate(lmsControl,LMS_CH_TX,ch-1,bandwidth_MHz * 1e6,useExtLoopback);
-    }
-    if (status != 0)
-        wxMessageBox(wxString::Format(_("Tx calibration: %s"), wxString::From8BitData(LMS_GetLastErrorMessage())));
-    {
-#ifdef NDEBUG
-        wxBusyInfo wait("Please wait, calibrating receiver...");
-#endif
-        status = LMS_Calibrate(lmsControl,LMS_CH_RX,ch-1,bandwidth_MHz * 1e6,useExtLoopback);
-    }
-    if (status != 0)
-        wxMessageBox(wxString::Format(_("Rx calibration: %s"), wxString::From8BitData(LMS_GetLastErrorMessage())));
+    int status = LMS_Calibrate(lmsControl,LMS_CH_TX,ch-1,bandwidth_MHz * 1e6,useExtLoopback);
 
-    wxMessageBox(_("Calibration Finished"), _("Info"), wxOK, this);
+    if (status != 0)
+    {
+        wxMessageBox(wxString::Format(_("Tx Calibration Failed: %s"), LMS_GetLastErrorMessage()), _("Info"), wxOK, this);
+        UpdateGUI();
+        return;
+    }
+
+    status |= LMS_Calibrate(lmsControl,LMS_CH_RX,ch-1,bandwidth_MHz * 1e6,useExtLoopback);
+    if (status != 0)
+        wxMessageBox(wxString::Format(_("Rx Calibration Failed: %s"), LMS_GetLastErrorMessage()), _("Info"), wxOK, this);
+    else
+        wxMessageBox(_("Calibration Finished"), _("Info"), wxOK, this);
     UpdateGUI();
 }
 
@@ -144,7 +142,7 @@ void lms7002_pnlCalibrations_view::Initialize(lms_device_t* pControl)
     lmsControl = pControl;
     assert(lmsControl != nullptr);
     uint16_t value;
-    if (!LMS_IsOpen(lmsControl,0) || LMS_ReadParam(lmsControl,LMS7param(MASK),&value)!=0  || value != 0)
+    if (LMS_ReadParam(lmsControl,LMS7param(MASK),&value)!=0  || value != 0)
         value = 1;
     chkDCMODE->Enable(value);
 }
@@ -219,3 +217,11 @@ void lms7002_pnlCalibrations_view::UpdateGUI()
     LMS_GetClockFreq(lmsControl,LMS_CLOCK_REF,&freq);
     lblCGENrefClk->SetLabel(wxString::Format(_("%f"), freq/1e6));
 }
+
+void lms7002_pnlCalibrations_view::OnCalibrationMethodChange( wxCommandEvent& event )
+{
+    if(rgrCalibrationMethod->GetSelection() == 0)
+        lblCalibrationNote->SetLabel("");
+    else
+        lblCalibrationNote->SetLabel("Some boards might not have onboard loopback for selected Rx/Tx paths");
+}
