@@ -1,4 +1,5 @@
 #include "LMS7002M.h"
+#include "Logger.h"
 using namespace lime;
 
 int LMS7002M::CalibrateTxGainSetup()
@@ -6,6 +7,25 @@ int LMS7002M::CalibrateTxGainSetup()
     int status;
     int ch = Get_SPI_Reg_bits(LMS7param(MAC));
 
+    uint16_t value = SPI_read(0x0020);
+    if( (value & 3) == 1)
+        value = value | 0x0014;
+    else
+        value = value | 0x0028;
+    SPI_write(0x0020, value);
+
+    //RxTSP
+    SetDefaults(RxTSP);
+    SetDefaults(RxNCO);
+    Modify_SPI_Reg_bits(LMS7param(AGC_MODE_RXTSP), 1);
+    Modify_SPI_Reg_bits(LMS7param(AGC_AVG_RXTSP), 1);
+    Modify_SPI_Reg_bits(LMS7param(HBD_OVR_RXTSP), 1);
+    Modify_SPI_Reg_bits(LMS7param(CMIX_BYP_RXTSP), 1);
+
+    //TBB
+    Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB), 1);
+    Modify_SPI_Reg_bits(LMS7param(LOOPB_TBB), 3);
+
     //RFE
     Modify_SPI_Reg_bits(LMS7param(EN_G_RFE), 0);
     Modify_SPI_Reg_bits(0x010D, 4, 1, 0xF);
@@ -20,10 +40,6 @@ int LMS7002M::CalibrateTxGainSetup()
     //TRF
     Modify_SPI_Reg_bits(LMS7param(EN_G_TRF), 0);
 
-    //TBB
-    Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB), 1);
-    Modify_SPI_Reg_bits(LMS7param(LOOPB_TBB), 3);
-
     //AFE
     const int isel_dac_afe = Get_SPI_Reg_bits(LMS7param(ISEL_DAC_AFE));
     SetDefaults(AFE);
@@ -80,38 +96,36 @@ int LMS7002M::CalibrateTxGainSetup()
     LoadDC_REG_IQ(LMS7002M::Tx, tsgValue , tsgValue);
     SetNCOFrequency(LMS7002M::Tx, 0, 0.5e6);
 
-    //RxTSP
-    SetDefaults(RxTSP);
-    SetDefaults(RxNCO);
-    Modify_SPI_Reg_bits(LMS7param(AGC_MODE_RXTSP), 1);
-    Modify_SPI_Reg_bits(LMS7param(AGC_AVG_RXTSP), 1);
-    Modify_SPI_Reg_bits(LMS7param(HBD_OVR_RXTSP), 1);
-    Modify_SPI_Reg_bits(LMS7param(CMIX_BYP_RXTSP), 1);
     return 0;
 }
 
 int LMS7002M::CalibrateTxGain(float maxGainOffset_dBFS, float *actualGain_dBFS)
 {
+    if (!controlPort){
+        lime::error("No device connected");
+        return -1;
+    }
     int status;
     int cg_iamp;
     auto registersBackup = BackupRegisterMap();
     status = CalibrateTxGainSetup();
     if(status == 0)
     {
-        uint32_t rssi = GetRSSI();
         cg_iamp = Get_SPI_Reg_bits(LMS7param(CG_IAMP_TBB));
-        while(rssi < 0x7FFF && cg_iamp <= 63)
+        while(GetRSSI() < 0x7FFF)
         {
-            ++cg_iamp;
-            if(cg_iamp > 63)
+            if(++cg_iamp > 63)
                 break;
             Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB), cg_iamp);
-            rssi = GetRSSI();
         }
     }
     RestoreRegisterMap(registersBackup);
+
+    int ind = Get_SPI_Reg_bits(LMS7_MAC);
+    opt_gain_tbb[ind] = cg_iamp > 1 ? cg_iamp-1 : 1;
+
     if (status == 0)
-        Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB), cg_iamp-1);
+        Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB), opt_gain_tbb[ind]);
     //logic reset
     Modify_SPI_Reg_bits(LMS7param(LRST_TX_A), 0);
     Modify_SPI_Reg_bits(LMS7param(LRST_TX_B), 0);
